@@ -1,4 +1,6 @@
-<?xml version="1.0" ?><!DOCTYPE TS><TS language="de" version="2.1">
+<?xml version="1.0" encoding="utf-8"?>
+<!DOCTYPE TS>
+<TS version="2.1" language="de">
 <context>
     <name>AboutDialog</name>
     <message>
@@ -1279,7 +1281,7 @@
     </message>
     <message>
         <source>Analyze Game</source>
-        <translation>Spiel analysieren</translation>
+        <translation type="vanished">Spiel analysieren</translation>
     </message>
     <message>
         <source>A</source>
@@ -1505,12 +1507,82 @@
     </message>
     <message>
         <source>Game</source>
+        <translation type="vanished">Spiel</translation>
+    </message>
+    <message>
+        <source>Result</source>
+        <translation type="vanished">Ergebnis</translation>
+    </message>
+    <message>
+        <source>Win</source>
+        <extracomment>Result of rated game is a win</extracomment>
+        <translation type="vanished">Gewinn</translation>
+    </message>
+    <message>
+        <source>Loss</source>
+        <extracomment>Result of rated game is a loss</extracomment>
+        <translation type="vanished">Verlust</translation>
+    </message>
+    <message>
+        <source>Tie</source>
+        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
+        <translation type="vanished">Unentsch.</translation>
+    </message>
+    <message>
+        <source>Level</source>
+        <translation type="vanished">Stufe</translation>
+    </message>
+    <message>
+        <source>Your Color</source>
+        <translation type="vanished">Ihre Farbe</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation type="vanished">Datum</translation>
+    </message>
+    <message>
+        <source>Open Game %1</source>
+        <translation type="vanished">Spiel %1 öffnen</translation>
+    </message>
+</context>
+<context>
+    <name>SaveDialog</name>
+    <message>
+        <source>Save</source>
+        <translation>Speichern</translation>
+    </message>
+    <message>
+        <source>Blokus games</source>
+        <translation>Blokus-Partien</translation>
+    </message>
+</context>
+<context>
+    <name>TableModel</name>
+    <message>
+        <source>Game</source>
+        <extracomment>Table header for game number in rating dialog</extracomment>
         <translation>Spiel</translation>
     </message>
     <message>
         <source>Result</source>
+        <extracomment>Table header for game result in rating dialog</extracomment>
         <translation>Ergebnis</translation>
     </message>
+    <message>
+        <source>Level</source>
+        <extracomment>Table header for level in rating dialog</extracomment>
+        <translation>Stufe</translation>
+    </message>
+    <message>
+        <source>Your Color</source>
+        <extracomment>Table header for player color(s) in rating dialog</extracomment>
+        <translation>Ihre Farbe</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <extracomment>Table header for game date in rating dialog</extracomment>
+        <translation>Datum</translation>
+    </message>
     <message>
         <source>Win</source>
         <extracomment>Result of rated game is a win</extracomment>
@@ -1526,33 +1598,6 @@
         <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
         <translation>Unentsch.</translation>
     </message>
-    <message>
-        <source>Level</source>
-        <translation>Stufe</translation>
-    </message>
-    <message>
-        <source>Your Color</source>
-        <translation>Ihre Farbe</translation>
-    </message>
-    <message>
-        <source>Date</source>
-        <translation>Datum</translation>
-    </message>
-    <message>
-        <source>Open Game %1</source>
-        <translation>Spiel %1 öffnen</translation>
-    </message>
-</context>
-<context>
-    <name>SaveDialog</name>
-    <message>
-        <source>Save</source>
-        <translation>Speichern</translation>
-    </message>
-    <message>
-        <source>Blokus games</source>
-        <translation>Blokus-Partien</translation>
-    </message>
 </context>
 <context>
     <name>ToolBar</name>
@@ -1693,4 +1738,4 @@
         <translation>Zu viele Argumente</translation>
     </message>
 </context>
-</TS>
\ No newline at end of file
+</TS>
