@@ -1281,7 +1281,7 @@
     </message>
     <message>
         <source>Analyze Game</source>
-        <translation>Analizar partida</translation>
+        <translation type="vanished">Analizar partida</translation>
     </message>
     <message>
         <source>A</source>
@@ -1507,12 +1507,82 @@
     </message>
     <message>
         <source>Game</source>
+        <translation type="vanished">Partida</translation>
+    </message>
+    <message>
+        <source>Result</source>
+        <translation type="vanished">Resultado</translation>
+    </message>
+    <message>
+        <source>Win</source>
+        <extracomment>Result of rated game is a win</extracomment>
+        <translation type="vanished">Victoria</translation>
+    </message>
+    <message>
+        <source>Loss</source>
+        <extracomment>Result of rated game is a loss</extracomment>
+        <translation type="vanished">Derrota</translation>
+    </message>
+    <message>
+        <source>Tie</source>
+        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
+        <translation type="vanished">Empate</translation>
+    </message>
+    <message>
+        <source>Level</source>
+        <translation type="vanished">Nivel</translation>
+    </message>
+    <message>
+        <source>Your Color</source>
+        <translation type="vanished">Su color</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <translation type="vanished">Fecha</translation>
+    </message>
+    <message>
+        <source>Open Game %1</source>
+        <translation type="vanished">Abrir partida %1</translation>
+    </message>
+</context>
+<context>
+    <name>SaveDialog</name>
+    <message>
+        <source>Save</source>
+        <translation>Guardar</translation>
+    </message>
+    <message>
+        <source>Blokus games</source>
+        <translation>Partidas de Blokus</translation>
+    </message>
+</context>
+<context>
+    <name>TableModel</name>
+    <message>
+        <source>Game</source>
+        <extracomment>Table header for game number in rating dialog</extracomment>
         <translation>Partida</translation>
     </message>
     <message>
         <source>Result</source>
+        <extracomment>Table header for game result in rating dialog</extracomment>
         <translation>Resultado</translation>
     </message>
+    <message>
+        <source>Level</source>
+        <extracomment>Table header for level in rating dialog</extracomment>
+        <translation>Nivel</translation>
+    </message>
+    <message>
+        <source>Your Color</source>
+        <extracomment>Table header for player color(s) in rating dialog</extracomment>
+        <translation>Su color</translation>
+    </message>
+    <message>
+        <source>Date</source>
+        <extracomment>Table header for game date in rating dialog</extracomment>
+        <translation>Fecha</translation>
+    </message>
     <message>
         <source>Win</source>
         <extracomment>Result of rated game is a win</extracomment>
@@ -1528,33 +1598,6 @@
         <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
         <translation>Empate</translation>
     </message>
-    <message>
-        <source>Level</source>
-        <translation>Nivel</translation>
-    </message>
-    <message>
-        <source>Your Color</source>
-        <translation>Su color</translation>
-    </message>
-    <message>
-        <source>Date</source>
-        <translation>Fecha</translation>
-    </message>
-    <message>
-        <source>Open Game %1</source>
-        <translation>Abrir partida %1</translation>
-    </message>
-</context>
-<context>
-    <name>SaveDialog</name>
-    <message>
-        <source>Save</source>
-        <translation>Guardar</translation>
-    </message>
-    <message>
-        <source>Blokus games</source>
-        <translation>Partidas de Blokus</translation>
-    </message>
 </context>
 <context>
     <name>ToolBar</name>
